@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 9742 2017-02-08 01:01:19Z David $
+# $Id: __init__.py 9766 2017-02-21 03:21:39Z David $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $ (last)
-# $Date: 2017-02-08 09:01:19 +0800 (Wed, 08 Feb 2017) $
-# $Revision: 9742 $
+# $Date: 2017-02-21 11:21:39 +0800 (Tue, 21 Feb 2017) $
+# $Revision: 9766 $
 
 import os
 import sys
@@ -134,7 +134,20 @@ def attachSettings(settingsDict, enablePaypal=False):
         os.path.dirname(os.path.realpath(settingsDict['__file__'])), x)
 
     if settingsDict['DEBUG']:
-        STATIC_ROOT = location('static')
+        addStaticRoot = {
+            'STATIC_ROOT': location('static')
+        }
+        update(settingsDict, addStaticRoot)
+    elif settingsDict['DEBUG'] == False:
+        ADD_STATICFILES_FINDERS = {
+            'STATICFILES_FINDERS': [
+                'django.contrib.staticfiles.finders.FileSystemFinder',
+                'django.contrib.staticfiles.finders.AppDirectoriesFinder',
+                'compressor.finders.CompressorFinder',
+            ]
+        }
+        update(settingsDict, ADD_STATICFILES_FINDERS)
+
     #=========================================================================
 
     #=========================================================================
